/*
Example for UT_7_SEG Click

    Date          : Jun 2017.
    Author        : Danilo M.

Test configuration STM :
    
    MCU             : STM32F107VCT6
    Dev. Board      : EasyMx PRO v7 for STM32 ARM
    SW              : mikroC PRO for ARM v5.1.0

Description :

    This example shows countdown from 99 to 00, the LED driver Max6969 is programmed via SPI,
    and the brightness of 7 seg display is regulated by duty cycle of PWM.

*/

#include "stdint.h"

sbit   MAX6969_LE_PIN   at  GPIOD_ODR.B13;

uint16_t pwmPeriod;
static const uint8_t minus_char = 0x40;

void systemInit()
{
    GPIO_Digital_Output( &GPIOD_BASE, _GPIO_PINMASK_13 );
    SPI3_Init_Advanced(_SPI_FPCLK_DIV16,_SPI_MASTER |_SPI_8_BIT |_SPI_CLK_IDLE_LOW 
    |_SPI_SECOND_CLK_EDGE_TRANSITION |_SPI_SS_DISABLE |_SPI_SSM_ENABLE | _SPI_SSI_1, &_GPIO_MODULE_SPI3_PC10_11_12);
    pwmPeriod = PWM_TIM5_Init(1000);
    PWM_TIM5_Set_Duty(pwmPeriod,  _PWM_NON_INVERTED, _PWM_CHANNEL1);
    PWM_TIM5_Start(_PWM_CHANNEL1, &_GPIO_MODULE_TIM5_CH1_PA0);

}

void MAX6969_Chip_Select()
{
    MAX6969_LE_PIN = 1;
    asm nop
    asm nop
    asm nop
    MAX6969_LE_PIN = 0;
}

static void U7SEG_Write(uint8_t number)
{
    char numbers[10] = {0x3F, 0x06, 0x5B, 0x4F, 0x66, 0x6D, 0x7D, 0x07, 0x7F, 0x6F};
    uint8_t tens = number / 10;
    uint8_t ones = number % 10;
    if (number > 99) return;

    SPI_Wr_Ptr(numbers[ones]);
    SPI_Wr_Ptr(numbers[tens]);
}

void main()
{
    uint8_t counter;

    systemInit();
    counter = 100;

    while(counter--)
    {
        U7SEG_Write(counter);
        MAX6969_Chip_Select();
        Delay_ms(500);
    }

    SPI_Wr_Ptr(minus_char);
    SPI_Wr_Ptr(minus_char);
    MAX6969_Chip_Select();
}